@@ -19,12 +19,10 @@ class Regbot:
     loaded_model = joblib.load(open(f'{cls.reg_model_path}', 'rb'))
     return loaded_model
 
-
   @classmethod
-  def prepareInput(cls,opening,closing,volume):
-  	ask_ind = closing*volume/(opening + closing)
-  	bid_ind = opening*volume/(opening + closing)
-  	testdata = np.array([[ask_ind,bid_ind]])
+  def prepareInput(cls,opening,closing,bvr):
+  	bvr = opening/(opening + closing)
+  	testdata = np.array([[opening,closing,bvr]])
   	scaler = joblib.load(f'{cls.model_scaler_path}')
   	testdata = scaler.transform(testdata)
 
@@ -32,16 +30,16 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing,volume):
-    scalledInput = cls.prepareInput(opening,closing,volume)
-    return cls.loadmodel().predict(scalledInput)[0].round()
+  def buySignalGenerator(cls,opening,closing,bvr):
+    scalledInput = cls.prepareInput(opening,closing,bvr)
+    return cls.loadmodel().predict(scalledInput)[0]
 
 
 
 
-def signal(opening,closing,volume):
+def signal(opening,closing,bvr):
   try:
-    return Regbot.buySignalGenerator(opening,closing,volume)
+    return Regbot.buySignalGenerator(opening,closing,bvr)
   except Exception as e:
     print(e)
 
